from setuptools import setup, find_packages
classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Education',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
]
setup(
    name='datorogava',
    version='0.0.1',
    classifiers=classifiers,
    packages=find_packages(),
    license='MIT',
    install_requires=[""]
)